@@ -21,6 +21,7 @@
 
 /* Conditional compat-layer for Gtk+ 3.19.1+ */
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 void
 __attribute__((weak)) gtk_widget_class_set_css_name (GtkWidgetClass *widget_class, const char *name);
 void
@@ -30,7 +31,9 @@ plank_compat_gtk_widget_class_set_css_name (GtkWidgetClass *widget_class, const
 		gtk_widget_class_set_css_name (widget_class, name);
 	}
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 void
 __attribute__((weak)) gtk_widget_path_iter_set_object_name (GtkWidgetPath *path, gint pos, const char *name);
 void
@@ -40,3 +43,4 @@ plank_compat_gtk_widget_path_iter_set_object_name (GtkWidgetPath *path, gint pos
 		gtk_widget_path_iter_set_object_name (path, pos, name);
 	}
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
